Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7767)

Unified Diff: chrome/renderer/content_settings_observer.h

Issue 1906533002: Add 'autoplay' content settings and expose it to Blink. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/renderer/content_settings_observer.h
diff --git a/chrome/renderer/content_settings_observer.h b/chrome/renderer/content_settings_observer.h
index 97af499407e56bd326bb262e5670097827162e45..f5b88c88f9ba877c850971e8bd6d739f97dfbcd4 100644
--- a/chrome/renderer/content_settings_observer.h
+++ b/chrome/renderer/content_settings_observer.h
@@ -42,9 +42,9 @@ class ContentSettingsObserver
bool should_whitelist);
~ContentSettingsObserver() override;
// Sets the content setting rules which back |AllowImage()|, |AllowScript()|,
// and |AllowScriptFromSource()|. |content_setting_rules| must outlive this
// |ContentSettingsObserver|.
void SetContentSettingRules(
const RendererContentSettingRules* content_setting_rules);
@@ -84,6 +84,7 @@ class ContentSettingsObserver
bool allowRunningInsecureContent(bool allowed_per_settings,
const blink::WebSecurityOrigin& context,
const blink::WebURL& url) override;
+ bool allowAutoplay(bool default_value) override;
private:
FRIEND_TEST_ALL_PREFIXES(ContentSettingsObserverTest, WhitelistedSchemes);
@@ -42,9 +42,9 @@ class ContentSettingsObserver
bool should_whitelist);
~ContentSettingsObserver() override;
- // Sets the content setting rules which back |AllowImage()|, |AllowScript()|,
- // and |AllowScriptFromSource()|. |content_setting_rules| must outlive this
- // |ContentSettingsObserver|.
+ // Sets the content setting rules which back |allowImage()|, |allowScript()|,
+ // |allowScriptFromSource()| and |allowAutoplay()|. |content_setting_rules|
+ // must outlive this |ContentSettingsObserver|.
void SetContentSettingRules(
const RendererContentSettingRules* content_setting_rules);

Powered by Google App Engine
This is Rietveld 408576698